@@ -38,7 +38,7 @@ module Diagrams.BoundingBox
   , boxExtents, boxCenter
   , mCenterPoint, centerPoint
   , boxTransform, boxFit
-  , contains, contains', boundingBoxQuery
+  , contains, contains'
   , inside, inside', outside, outside'
 
     -- * Operations on bounding boxes
@@ -55,7 +55,8 @@ import           Diagrams.Align
 import           Diagrams.Core
 import           Diagrams.Core.Transform
 import           Diagrams.Path
-import           Diagrams.ThreeD.Shapes
+import           Diagrams.Query
+import           Diagrams.ThreeD.Shapes  (cube)
 import           Diagrams.ThreeD.Types
 import           Diagrams.TwoD.Path      ()
 import           Diagrams.TwoD.Shapes
@@ -118,8 +119,12 @@ instance (Additive v, Num n) => HasOrigin (BoundingBox v n) where
     = fromMaybeEmpty
     (NonEmptyBoundingBox . mapT (moveOriginTo p) <$> getCorners b)
 
+instance (Additive v, Foldable v, Ord n)
+     => HasQuery (BoundingBox v n) Any where
+  getQuery bb = Query $ Any . contains bb
+
 instance (Metric v, Traversable v, OrderedField n)
-          => Enveloped (BoundingBox v n) where
+     => Enveloped (BoundingBox v n) where
   getEnvelope = getEnvelope . getAllCorners
 
 -- Feels like cheating.
@@ -130,9 +135,8 @@ instance RealFloat n => Traced (BoundingBox V2 n) where
            . getEnvelope
 
 instance TypeableFloat n => Traced (BoundingBox V3 n) where
-  getTrace = getTrace
-           . ((`boxFit` cube) . boundingBox :: Envelope V3 n -> D V3 n)
-           . getEnvelope
+  getTrace bb = foldMap (\tr -> getTrace $ transform tr cube) $
+                boxTransform (boundingBox cube) bb
 
 instance (Metric v, Traversable v, OrderedField n) => Alignable (BoundingBox v n) where
   defaultBoundary = envelopeP
@@ -256,9 +260,6 @@ contains' b p = maybe False check $ getCorners b
     check (l, h) = F.and (liftI2 (<) l p)
                 && F.and (liftI2 (<) p h)
 
-boundingBoxQuery :: (Additive v, Foldable v, Ord n) => BoundingBox v n -> Query v n Any
-boundingBoxQuery bb = Query $ Any . contains bb
-
 -- | Test whether the first bounding box is contained inside
 --   the second.
 inside :: (Additive v, Foldable v, Ord n) => BoundingBox v n -> BoundingBox v n -> Bool
@@ -310,4 +311,3 @@ intersection u v = maybe mempty (uncurry fromCorners) $ do
 --   function is just an alias for @mappend@.
 union :: (Additive v, Ord n) => BoundingBox v n -> BoundingBox v n -> BoundingBox v n
 union = mappend
-
