@@ -67,7 +67,6 @@ import           Diagrams.Path
 import           Diagrams.Points         (centroid)
 import           Diagrams.Trail
 import           Diagrams.TrailLike
-import           Diagrams.TwoD.Transform
 import           Diagrams.TwoD.Types
 import           Diagrams.TwoD.Vector    (leftTurn, unitX, unitY, unit_Y)
 import           Diagrams.Util           (tau, ( # ))
@@ -222,6 +221,8 @@ orient :: OrderedField n => V2 n -> Located (Trail V2 n) -> Transformation V2 n
 orient v = orientPoints v . trailVertices
 
 orientPoints :: OrderedField n => V2 n -> [Point V2 n] -> Transformation V2 n
+orientPoints _ [] = mempty
+orientPoints _ [_] = mempty
 orientPoints v xs = rotation a
   where
     (n1,x,n2) = maximumBy (comparing (distAlong v . sndOf3))
