@@ -23,7 +23,6 @@ module Diagrams.TwoD.Transform
          T2
          -- * Rotation
        , rotation, rotate, rotateBy, rotated
-
        , rotationAround, rotateAround
        , rotationTo, rotateTo
 
@@ -43,6 +42,7 @@ module Diagrams.TwoD.Transform
          -- * Reflection
        , reflectionX, reflectX
        , reflectionY, reflectY
+       , reflectionXY, reflectXY
        , reflectionAbout, reflectAbout
 
          -- * Shears
@@ -63,34 +63,12 @@ import           Control.Lens            hiding (at, transform)
 import           Data.Semigroup
 
 import           Linear.Affine
+import           Linear.V2
 import           Linear.Vector
 
 -- Rotation ------------------------------------------------
 
--- | Create a transformation which performs a rotation about the local
---   origin by the given angle.  See also 'rotate'.
-rotation :: Floating n => Angle n -> T2 n
-rotation theta = fromLinear r (linv r)
-  where
-    r               = rot theta <-> rot (negated theta)
-    rot th (V2 x y) = V2 (cosA th * x - sinA th * y)
-                         (sinA th * x + cosA th * y)
-
--- | Rotate about the local origin by the given angle. Positive angles
---   correspond to counterclockwise rotation, negative to
---   clockwise. The angle can be expressed using any of the 'Iso's on
---   'Angle'.  For example, @rotate (1\/4 \@\@ 'turn')@, @rotate
---   (tau\/4 \@\@ rad)@, and @rotate (90 \@\@ deg)@ all
---   represent the same transformation, namely, a counterclockwise
---   rotation by a right angle.  To rotate about some point other than
---   the local origin, see 'rotateAbout'.
---
---   Note that writing @rotate (1\/4)@, with no 'Angle' constructor,
---   will yield an error since GHC cannot figure out which sort of
---   angle you want to use.  In this common situation you can use
---   'rotateBy', which interprets its argument as a number of turns.
-rotate :: (InSpace V2 n t, Transformable t, Floating n) => Angle n -> t -> t
-rotate = transform . rotation
+-- For the definitions of 'rotation' and 'rotate', see Diagrams.Angle.
 
 -- | A synonym for 'rotate', interpreting its argument in units of
 -- turns; it can be more convenient to write @rotateBy (1\/4)@ than
@@ -205,6 +183,8 @@ translateY :: (InSpace v n t, R2 v, Transformable t)
   => n -> t -> t
 translateY = transform . translationY
 
+
+
 -- Reflection ----------------------------------------------
 
 -- | Construct a transformation which flips a diagram from left to
@@ -227,13 +207,25 @@ reflectionY = fromSymmetric $ (_y *~ (-1)) <-> (_y *~ (-1))
 reflectY :: (InSpace v n t, R2 v, Transformable t) => t -> t
 reflectY = transform reflectionY
 
+-- | Construct a transformation which flips the diagram about x=y, i.e.
+--   sends the point (x,y) to (y,x).
+reflectionXY :: (Additive v, R2 v, Num n) => Transformation v n
+reflectionXY = fromSymmetric $ (_xy %~ view _yx) <-> (_xy %~ view _yx)
+
+-- | Flips the diagram about x=y, i.e. send the point (x,y) to (y,x).
+reflectXY :: (InSpace v n t, R2 v, Transformable t) => t -> t
+reflectXY = transform reflectionXY
+
 -- | @reflectionAbout p d@ is a reflection in the line determined by
 --   the point @p@ and direction @d@.
 reflectionAbout :: OrderedField n => P2 n -> Direction V2 n -> T2 n
 reflectionAbout p d =
-  conjugate (rotationTo d <> translation (origin .-. p))
+  conjugate (rotationTo (reflectY d) <> translation (origin .-. p))
             reflectionY
 
+
+
+
 -- | @reflectAbout p d@ reflects a diagram in the line determined by
 --   the point @p@ and direction @d@.
 reflectAbout :: (InSpace V2 n t, OrderedField n, Transformable t)
@@ -280,4 +272,3 @@ shearingY d = fromLinear (sh f g d  <-> sh f g (-d))
 --   @(1,0)@ to @(1,d)@.
 shearY :: (InSpace V2 n t, Transformable t) => n -> t -> t
 shearY = transform . shearingY
-
